@@ -1,10 +1,11 @@
 from dagster.core.utils import check_dagster_package_version
 
+from .executor import k8s_job_executor
 from .job import DagsterK8sJobConfig, construct_dagster_k8s_job
 from .launcher import K8sRunLauncher
-from .scheduler import K8sScheduler
+from .ops.k8s_job_op import k8s_job_op
 from .version import __version__
 
-check_dagster_package_version('dagster-k8s', __version__)
+check_dagster_package_version("dagster-k8s", __version__)
 
-__all__ = ['K8sRunLauncher']
+__all__ = ["K8sRunLauncher"]
